﻿## This file contains options that can be changed to customize your game.
##
## Lines beginning with two '#' marks are comments, and you shouldn't uncomment
## them. Lines beginning with a single '#' mark are commented-out code, and you
## may want to uncomment them when appropriate.


## Basics ######################################################################

## A human-readable name of the game. This is used to set the default window
## title, and shows up in the interface and error reports.
##
## The _() surrounding the string marks it as eligible for translation.

define config.name = _("glory_hole")


## Determines if the title given above is shown on the main menu screen. Set
## this to False to hide the title.

define gui.show_name = True


## The version of the game.

define config.version = "1.0"


## Text that is placed on the game's about screen. To insert a blank line
## between paragraphs, write \n\n.

define gui.about = _("")


## A short name for the game used for executables and directories in the built
## distribution. This must be ASCII-only, and must not contain spaces, colons,
## or semicolons.

define build.name = "glory_hole"


## Sounds and music ############################################################

## These three variables control which mixers are shown to the player by
## default. Setting one of these to False will hide the appropriate mixer.

define config.has_sound = True
define config.has_music = True
define config.has_voice = True


## To allow the user to play a test sound on the sound or voice channel,
## uncomment a line below and use it to set a sample sound to play.

# define config.sample_sound = "sample-sound.ogg"
# define config.sample_voice = "sample-voice.ogg"


## Uncomment the following line to set an audio file that will be played while
## the player is at the main menu. This file will continue playing into the
## game, until it is stopped or another file is played.

# define config.main_menu_music = "main-menu-theme.ogg"


## Transitions #################################################################
##
## These variables set transitions that are used when certain events occur.
## Each variable should be set to a transition, or None to indicate that no
## transition should be used.

## Entering or exiting the game menu.

define config.enter_transition = dissolve
define config.exit_transition = dissolve


## A transition that is used after a game has been loaded.

define config.after_load_transition = None


## Used when entering the main menu after the game has ended.

define config.end_game_transition = None


## A variable to set the transition used when the game starts does not exist.
## Instead, use a with statement after showing the initial scene.


## Window management ###########################################################
##
## This controls when the dialogue window is displayed. If "show", it is always
## displayed. If "hide", it is only displayed when dialogue is present. If
## "auto", the window is hidden before scene statements and shown again once
## dialogue is displayed.
##
## After the game has started, this can be changed with the "window show",
## "window hide", and "window auto" statements.

define config.window = "auto"


## Transitions used to show and hide the dialogue window

define config.window_show_transition = Dissolve(.2)
define config.window_hide_transition = Dissolve(.2)






#██▓▒░ *START* IMAGEMAP MAIN MENU ░▒▓█████████████████████████████████████ 
#This block is responsible for the Imagemap based main menu
screen main_menu:
    #tag menu





    
    
    imagemap:
        ground 'gui/UI_7.jpg'
        idle 'gui/UI_7.jpg'
        hover 'gui/UI_15.png'

        alpha False
    
        

        hotspot (375, 0, 148, 148) action Jump("budget_room") hovered [ Play ("test_one", "sfx/click.wav")]        
        hotspot (700, 0, 148, 148) action Jump("glory_room") hovered [ Play ("test_one", "sfx/click.wav")]
        hotspot (550, 290, 148, 148) action Jump("queen_room") hovered [ Play ("test_one", "sfx/click.wav")]
        hotspot (40, 400, 148, 148) action Jump("nobless_room") hovered [ Play ("test_one", "sfx/click.wav")]
        hotspot (355, 345, 148, 148) action Jump("diplomat_room") hovered [ Play ("test_two", "sfx/click.wav")]
        hotspot (525, 520, 148, 148) action Jump("richelieu_room") hovered [ Play ("test_three", "sfx/click.wav")]
        hotspot (770, 370, 148, 148) action Jump("turenne_room") hovered [ Play ("test_four", "sfx/click.wav")]
        hotspot (1060, 515, 148, 148) action Jump("peason_room") hovered [ Play ("test_five", "sfx/click.wav")]

        #hotspot (18, 180, 148, 148) action Jump("queen_room") hovered [ Play ("test_five", "sfx/click.wav")]
        #hotspot (927, 207, 148, 148) action Jump("queen_room") hovered [ Play ("test_five", "sfx/click.wav")]
        #hotspot (1115, 260, 148, 148) action Jump("queen_room") hovered [ Play ("test_five", "sfx/click.wav")]
        

    #t "Round [game_round] \n Crown Treasure estimated at [gold] \n Your Glory rises to [glory] \n your popularity is [peason_love] \n promise round is [promise_round] "



        #hotspot (1030, 230, 1280, 630) clicked Jump(peason_room) hovered [ Play ("test_five", "sfx/click.wav")]

        #hotspot (773, 114, 191, 67) action Start() hovered [ Play ("test_one", "sfx/click.wav")]
        #hotspot (773, 114, 191, 67) action Start() hovered [ Play ("test_one", "sfx/click.wav")]
        #hotspot (773, 114, 191, 67) action Start() hovered [ Play ("test_one", "sfx/click.wav")]
        #hotspot (773, 114, 191, 67) action Start() hovered [ Play ("test_one", "sfx/click.wav")]


        #hotspot (773, 210, 191, 67) action ShowMenu('load') hovered [ Play ("test_two", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_main_menu_load.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        #hotspot (773, 306, 191, 67) action ShowMenu('preferences') hovered [ Play ("test_three", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_main_menu_config.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]
        #hotspot (773, 402, 191, 67) action Quit(confirm=False) hovered [ Play ("test_four", "sfx/click.wav"), Show("gui_tooltip", my_picture="gui/tooltip_main_menu_quit.png", my_tt_xpos=46, my_tt_ypos=518) ] unhovered [Hide("gui_tooltip")]

    
#██▓▒░ IMAGEMAP MAIN MENU *END*  ░▒▓█████████████████████████████████████

# https://lemmasoft.renai.us/forums/viewtopic.php?f=51&t=22410





screen peason_room:
    #tag menu
    
    imagemap:
        ground 'gui/peason_room3.jpg'
        idle 'gui/peason_room3.jpg'
        hover 'gui/peason_room3.jpg'
    
        #hotspot (0, 400, 260, 710) action Start() hovered [ Play ("test_one", "sfx/click.wav")]
        #hotspot (390, 450, 460, 510) action Start() hovered [ Play ("test_two", "sfx/click.wav")]
        #hotspot (530, 440, 730, 660) action Start() hovered [ Play ("test_three", "sfx/click.wav")]
        #hotspot (800, 310, 900, 600) action Start() hovered [ Play ("test_four", "sfx/click.wav")]
        #hotspot (1030, 430, 1280, 630) action Start() hovered [ Play ("test_five", "sfx/click.wav")]

        #hotspot (0, 200, 260, 710) action Return() hovered [ Play ("test_one", "sfx/click.wav")]


screen richelieu_room:
    #tag menu
    
    imagemap:
        ground 'gui/chapelle.jpg'
        idle 'gui/chapelle.jpg'
        hover 'gui/chapelle.jpg'
    
        
        #hotspot (530, 440, 730, 660) action Start() hovered [ Play ("test_three", "sfx/click.wav")]

        #hotspot (0, 200, 260, 710) action Return() hovered [ Play ("test_one", "sfx/click.wav")]



screen nobless_room:
    #tag menu
    
    imagemap:
        ground 'gui/salon_jardin.jpg'
        idle 'gui/salon_jardin.jpg'
        hover 'gui/salon_jardin.jpg'
    
        #add noble at right

        #hotspot (0, 200, 260, 710) action Return() hovered [ Play ("test_one", "sfx/click.wav")]


screen turenne_room:
    #tag menu
    
    imagemap:
        ground 'gui/turenne3.jpg'
        idle 'gui/turenne3.jpg'
        hover 'gui/turenne3.jpg'
    
        #add noble at right

        #hotspot (0, 200, 260, 710) action Return() hovered [ Play ("test_one", "sfx/click.wav")]


screen budget_room:
    #tag menu
    
    imagemap:
        ground 'gui/bureau.jpg'
        idle 'gui/bureau.jpg'
        hover 'gui/bureau.jpg'
    
        #add noble at right

        #hotspot (0, 200, 260, 710) action Return() hovered [ Play ("test_one", "sfx/click.wav")]



screen glory_room:
    #tag menu
    
    imagemap:
        ground 'gui/salon_glaces.jpg'
        idle 'gui/salon_glaces.jpg'
        hover 'gui/salon_glaces.jpg'
    
        #add noble at right

        #hotspot (0, 200, 260, 710) action Return() hovered [ Play ("test_one", "sfx/click.wav")]




screen queen_room:
    #tag menu
    
    imagemap:
        ground 'gui/queen_room.jpg'
        idle 'gui/queen_room.jpg'
        hover 'gui/queen_room.jpg'
    
        #add noble at right

        #hotspot (0, 200, 260, 710) action Return() hovered [ Play ("test_one", "sfx/click.wav")]

## Preference defaults #########################################################

## Controls the default text speed. The default, 0, is infinite, while any other
## number is the number of characters per second to type out.

default preferences.text_cps = 0


## The default auto-forward delay. Larger numbers lead to longer waits, with 0
## to 30 being the valid range.

default preferences.afm_time = 15


## Save directory ##############################################################
##
## Controls the platform-specific place Ren'Py will place the save files for
## this game. The save files will be placed in:
##
## Windows: %APPDATA\RenPy\<config.save_directory>
##
## Macintosh: $HOME/Library/RenPy/<config.save_directory>
##
## Linux: $HOME/.renpy/<config.save_directory>
##
## This generally should not be changed, and if it is, should always be a
## literal string, not an expression.

define config.save_directory = "glory_hole-1487502980"


## Icon ########################################################################
##
## The icon displayed on the taskbar or dock.

define config.window_icon = "gui/window_icon.png"


## Build configuration #########################################################
##
## This section controls how Ren'Py turns your project into distribution files.

init python:

    ## The following functions take file patterns. File patterns are case-
    ## insensitive, and matched against the path relative to the base directory,
    ## with and without a leading /. If multiple patterns match, the first is
    ## used.
    ##
    ## In a pattern:
    ##
    ## / is the directory separator.
    ##
    ## * matches all characters, except the directory separator.
    ##
    ## ** matches all characters, including the directory separator.
    ##
    ## For example, "*.txt" matches txt files in the base directory, "game/
    ## **.ogg" matches ogg files in the game directory or any of its
    ## subdirectories, and "**.psd" matches psd files anywhere in the project.

    ## Classify files as None to exclude them from the built distributions.

    build.classify('**~', None)
    build.classify('**.bak', None)
    build.classify('**/.**', None)
    build.classify('**/#**', None)
    build.classify('**/thumbs.db', None)

    ## To archive files, classify them as 'archive'.

    # build.classify('game/**.png', 'archive')
    # build.classify('game/**.jpg', 'archive')

    ## Files matching documentation patterns are duplicated in a mac app build,
    ## so they appear in both the app and the zip file.

    build.documentation('*.html')
    build.documentation('*.txt')

## A Google Play license key is required to download expansion files and perform
## in-app purchases. It can be found on the "Services & APIs" page of the Google
## Play developer console.

# define build.google_play_key = "..."


## The username and project name associated with an itch.io project, separated
## by a slash.

# define build.itch_project = "renpytom/test-project"




#██▓▒░ TOOLTIP  ░▒▓████████████████████████████████████████████  
#This block declares the Tooltip

screen gui_tooltip:
    add my_picture xpos my_tt_xpos ypos my_tt_ypos
    
    
#██▓▒░ CUSTOM SOUND CHANNEL  ░▒▓███████████████████████████████████ 
# This is the block where we declare the individual sound channels 
# that enables us to play several sound FX's without overlapping

init python:
    renpy.music.register_channel("test_one", "sfx", False)
    renpy.music.register_channel("test_two", "sfx", False)
    renpy.music.register_channel("test_three", "sfx", False)
    renpy.music.register_channel("test_four", "sfx", False)
    renpy.music.register_channel("test_five", "sfx", False)
    renpy.music.register_channel("test_six", "sfx", False)